pytakeout documentation
=======================
https://github.com/idlesign/pytakeout



Description
-----------

*Simplifies Python code extraction*

Here will be an introductory description.



Requirements
------------

1. Python 2.7+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart


